Daiquiri (Django version)
=========================

**A framework for the publication of scientific databases**

.. image:: https://travis-ci.org/aipescience/django-daiquiri.svg?branch=master
   :alt: Build Status
   :target: https://travis-ci.org/aipescience/django-daiquiri

.. image:: https://coveralls.io/repos/github/aipescience/django-daiquiri/badge.svg?branch=master
   :alt: Coverage Status
   :target: https://coveralls.io/github/aipescience/django-daiquiri?branch=master

.. image:: https://img.shields.io/pypi/v/django-daiquiri.svg?style=flat
   :alt: Latest Version
   :target: https://pypi.python.org/pypi/django-daiquiri/

.. image:: http://img.shields.io/badge/license-APACHE-blue.svg?style=flat
    :target: https://github.com/aipescience/django-daiquiri/blob/master/LICENSE

This project is currently in an early stage of development and by no means production ready.

The PHP version of Daiquiri can be found `here <https://github.com/aipescience/daiquiri>`_.
